/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

/* $Id: TaskWrapperParameters.java 473861 2006-11-12 03:51:14Z gregor $  */

package org.apache.lenya.cms.task;

import java.util.Map;

/**
 * The task wrapper parameters
 * @deprecated Use the usecase framework instead.
 */
public class TaskWrapperParameters extends ParameterWrapper {

    /**
     * <code>TASK_ID</code> The task id
     */
    public static final String TASK_ID = "task-id";
    /**
     * <code>WEBAPP_URL</code> The webapp URL
     */
    public static final String WEBAPP_URL = "webapp-url";
    /**
     * <code>PREFIX</code> The prefix
     */
    public static final String PREFIX = "wrapper";

    protected static final String[] REQUIRED_KEYS = { TASK_ID, WEBAPP_URL };

    /**
     * Ctor.
     * @param parameters The parameter map to use.
     */
    public TaskWrapperParameters(Map parameters) {
        super(parameters);
    }

    /**
     * Returns the required keys.
     * @return A string array.
     */
    public String[] getRequiredKeys() {
        return REQUIRED_KEYS;
    }

    /**
     * Returns the task ID.
     * @return A string.
     */
    public String getTaskId() {
        return get(TASK_ID);
    }

    /**
     * Returns the webapp URL.
     * @return A string.
     */
    public String getWebappUrl() {
        return get(WEBAPP_URL);
    }

    /**
     * Sets the webapp URL.
     * @param url A url.
     */
    public void setWebappUrl(String url) {
        put(WEBAPP_URL, url);
    }

    /**
     * Sets the task ID.
     * @param taskId A string.
     */
    public void setTaskId(String taskId) {
        put(TASK_ID, taskId);
    }

    /**
     * @see org.apache.lenya.cms.task.ParameterWrapper#getPrefix()
     */
    public String getPrefix() {
        return PREFIX;
    }

}
